# ZenFrame
Abstract part of the graphical interface of the ZenCad project. 

ZenFrame is a sandbox that controls the execution of python scripts with graphical output. ZenFrame implements the process control, inter process communication, settings storing etc. 